@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 from . import conf
+import traceback
 from ._version import __version__
 import os
 import pytest
 from _pytest.compat import NotSetType
-from .data import tmp
 from .common import constant, config as file, logger, common
 from .run import json_name
 from .pressure import case, httpBase
@@ -57,25 +57,6 @@ def pytest_generate_tests(metafunc):
         metafunc.parametrize("data", [])
 
 
-def pytest_runtest_setup(item):
-    param = item.callspec.params.get('data')
-    if param != NotSetType.token:
-        _id = param.get('id')
-        last = param.get('dependent')
-        if param.get('last_dependent') is not None:
-            last = param.get('last')
-        if last is not None:
-            item.callspec.params['data']['lastTmp'] = tmp.tmp.get_lastTmp(last)
-            item.callspec.params['data']['dpTmp'] = tmp.tmp.get(last)
-        if _id is not None:
-            tmp.tmp.append_lastTmp(param.get('id'), param.get('ins'))
-
-        logger.info('开始运行用例:{}'.format(param.get('title')))
-        logger.info(item.callspec.params.get('data'))
-        conf.settings.run.current_env = conf.settings.run.tag_env_list[param['tag']]
-        conf.settings.run.current_tag = param['tag']
-
-
 def pytest_runtest_call(__multicall__):
     """
     打印异常日志到日志文件内
@@ -85,5 +66,6 @@ def pytest_runtest_call(__multicall__):
     try:
         __multicall__.execute()
     except:
-        logger.exception("pytest_runtest_call caught exception:")
+        logger.error(traceback.format_exc())
         raise
+
