@@ -56,17 +56,13 @@ def run_case(data: list, _uuid: str, env: str):
         f.write(json.dumps(_data, sort_keys=True, indent=4, separators=(',', ':')))
 
     _path = os.path.join(constant.TMP_REPORTS_DIR, _uuid)
-    command = ['-s', '--capture=no', '-v', '--alluredir', _path, '--clean-alluredir',
+    command = ['-s', '--capture=no', '-vvv', '--alluredir', _path, '--clean-alluredir',
                '--cache-clear', '-W', 'ignore:Module already imported:pytest.PytestWarning', '--{}'.format(json_name),
                _uuid]
     logger.info('执行命令:{}'.format(command))
     pytest.main(command)
 
 
-def run_locust(data: list, _uuid: str, env: str):
-    ...
-
-
 class PropogateHandler(logging.Handler):
     def emit(self, record: logging.LogRecord) -> None:
         logging.getLogger(record.name).handle(record)
@@ -150,28 +146,19 @@ class Run(object):
         gevent.spawn(stats_history, runner)
         main_greenlet.join()
 
-    def get_env_name(self):
-        current_env = conf.settings.current_env
-        tag_name_list = conf.settings.run.get('tag_name_list', None)
-        if tag_name_list is None or current_env not in tag_name_list:
-            if conf.settings.exists('name'):
-                return conf.settings.name
-            else:
-                return current_env
-        else:
-            return conf.settings.run.tag_name_list[current_env]
-
     def run(self):
         self.init_dir()
         tag_name = ';'.join([conf.settings.run.tag_env_list[i] for i in conf.settings.run.test_tags])
         logger.info('开始使用 {} 个进程 {} {}(标签:{})的 {} 用例'.format(conf.settings.run.process_num,
                                                        '运行' if conf.settings.run.is_debug is False else '调试'
-                                                        , self.get_env_name(), tag_name,
+                                                        , conf.settings.get_env_name(), tag_name,
                                                        conf.settings.run.test_case))
         logger.info('开始收集测试用例。。。。。')
-        group, surplus_data = self.get_group_data()
+        group, surplus_data = self.collect_use_cases()
+
         group_length = len(group)
         surplus_length = len(surplus_data)
+
         logger.info('分组用例：{}'.format(group))
         logger.info('未分组用例：{}'.format(surplus_data))
 
@@ -209,9 +196,11 @@ class Run(object):
     def start_process(self, group_queue):
         total = group_queue.qsize()
         pro_list = []
+        import threading
         while len(pro_list) != 0 or group_queue.qsize() != 0:
             for pro in pro_list:
                 if pro.is_alive() is False:
+                # if pro.isAlive() is False:
                     name = pro.name
                     pro_list.remove(pro)
             if len(pro_list) < conf.settings.run.process_num and group_queue.qsize() > 0:
@@ -220,9 +209,13 @@ class Run(object):
                     _uuid = str(uuid.uuid4())
                     self.uuid_list.append(_uuid)
                     logger.info("执行进度:{}/{}".format(group_queue.qsize(), total))
-                    p = Process(target=run_case, args=(data, _uuid, conf.settings.current_env))
+                    p = threading.Thread(target=run_case, args=(data, _uuid, conf.settings.current_env))
+                    p.setName(_uuid)
                     p.start()
-                    p.name = _uuid
+
+                    # p = Process(target=run_case, args=(data, _uuid, conf.settings.current_env))
+                    # p.start()
+                    # p.name = _uuid
                     pro_list.append(p)
                 except Exception:
                     logger.error(traceback.format_exc())
@@ -230,15 +223,14 @@ class Run(object):
 
     def list_transformation_queue(self, _list) -> queue.Queue:
         _result = queue.Queue()
-        for i in range(len(_list)):
+        for i in list(range(len(_list)))[::-1]:
             _result.put(_list[len(_list) - 1 - i])
         del _list
         return _result
 
-    def get_group_data(self):
+    def collect_use_cases(self):
         group_data = []
         self.init_all_data()
-
         # 区分下渠道
         _all_data = {}
         for i in self.all_data:
@@ -271,9 +263,10 @@ class Run(object):
             if self.check_data(data):
                 continue
             if data.get('dependent') is not None and data.get('id') not in dependent_list:
-                _data = self.get_dependent_data(data, channel_data)
-                _data.reverse()
-                group.append(_data)
+                _data_list = self.get_dependent_data(data)
+                for _data in _data_list:
+                    _data.reverse()
+                    group.append(_data)
         return group
 
     def check_data(self, data, is_file=True):
@@ -340,27 +333,6 @@ class Run(object):
             return 1
         return 0
 
-    def get_dependent_data(self, data, all_data):
-        """
-        获取某个用例数据的依赖数据
-        :param data:
-        :param all_data:
-        :return:
-        """
-        _data = [data]
-        dependent = data.get('dependent')
-        channel = data.get('tag')
-        if channel is None:
-            return _data
-        if channel in list(self.all_data_by_channel_id.keys()) and \
-                dependent in list(self.all_data_by_channel_id[channel].keys()):
-            _dep = self.all_data_by_channel_id[channel].get(dependent)
-            if _dep.get('dependent') is not None:
-                _data += self.get_dependent_data(_dep, all_data)
-            else:
-                _data.append(_dep)
-        return _data
-
     def init_all_data(self):
         """
         获取所有用例数据
@@ -374,40 +346,43 @@ class Run(object):
                     _data = config.Json(_path).get_object()
                     if type(_data) != list or len(_data) == 0:
                         continue
-                    if _data[0].get('__file') is None:
-                        continue
-                    __file = _data[0].get('__file')
-                    __func = _data[0].get('__func')
-                    __dependent_class = _data[0].get('__dependent_class')
-                    if __func is None:
-                        __func = 'default'
-
+                    __init = _data[0]
+                    __init.setdefault('__file', 'test_default')
+                    __init.setdefault('__func', 'test_default')
                     for i in _data[1:]:
-                        i['__file'] = __file
-                        i['__func'] = __func
-                        i['__dependent_class'] = __dependent_class
-                        tags = i.get('tags')
-                        if tags is None:
-                            continue
-
-                        for tag in list(set(conf.settings.run.test_tags).intersection(tags)):
-                            subTags = i.get('subTags', ['default'])
-                            is_sub = True
-                            if isinstance(subTags, list) is False:
-                                subTags = ['default']
-                                is_sub = False
-                            for subTag in subTags:
-                                if i.get('id') is None:
-                                    i['id'] = str(uuid.uuid4())
-                                i['tag'] = tag
-                                i['subTag'] = subTag
-                                i['untag'] = 'uninfo' if tag == 'info' else 'info'
-                                if tag not in list(self.all_data_by_channel_id.keys()):
-                                    self.all_data_by_channel_id[tag] = {}
-                                self.all_data_by_channel_id[tag][i['id']] = copy.deepcopy(i)
-                                self.all_data.append(copy.deepcopy(i))
+                        case = copy.deepcopy(__init)
+                        case = common.NewDict(case)
+                        case.merge_dict(i)
+                        for tag in list(set(conf.settings.run.test_tags).intersection(set(case.getdefault('tags', [])))):
+                            case['tag'] = tag
+                            for subTag in case.getdefault('subTags', ['default']):
+                                if case.get('id') is None:
+                                    case['id'] = str(uuid.uuid4())
+                                case['subTag'] = subTag
+                                for sonTag in case.getdefault('sonTags', ['default']):
+                                    case['sonTag'] = sonTag
+                                    if tag not in list(self.all_data_by_channel_id.keys()):
+                                        self.all_data_by_channel_id[tag] = {}
+                                    if case['id'] not in self.all_data_by_channel_id[tag]:
+                                        self.all_data_by_channel_id[tag][case['id']] = []
+                                    self.all_data_by_channel_id[tag][case['id']].append(copy.deepcopy(case))
+                                    self.all_data.append(copy.deepcopy(case))
         self.replace_base_data()
 
+    def get_dependent_data(self, data):
+        result = []
+        dependent = data.get('dependent')
+        channel = data.get('tag')
+        if channel in list(self.all_data_by_channel_id.keys()) and \
+                dependent in list(self.all_data_by_channel_id[channel].keys()):
+            _dep_list = self.all_data_by_channel_id[channel].get(dependent)
+            for _dep in _dep_list:
+                if _dep.get('dependent') is not None:
+                    result += [[data] + i for i in self.get_dependent_data(_dep)]
+                else:
+                    result.append([data, _dep])
+        return result
+
     def replace_base_data(self):
         """
         替换继承数据
@@ -472,17 +447,8 @@ class Run(object):
         self.check_and_create_by_dir(constant.TMP_REPORT_DIR)
         self.check_and_create_by_dir(constant.TMP_REPORTS_DIR)
 
-    def get_env(self):
-        _list = []
-        _list.append(['环境:', self.get_env_name()])
-        tag_name = ';'.join([conf.settings.run.tag_name_list[i] for i in conf.settings.run.test_tags])
-        _list.append(['标签:', tag_name])
-        _list.append(['执行用例:', conf.settings.run.test_case])
-        _list.append(['并行数:', conf.settings.run.process_num])
-        return _list
-
     def update_environment(self, result_tmp):
-        environment = self.get_env()
+        environment = conf.settings._report.env
         xml = config.AllureXml()
         xml.append_child(environment)
         xml.save_path(os.path.join(result_tmp, 'environment.xml'))
@@ -529,9 +495,6 @@ class Run(object):
         self.update_environment(constant.TMP_REPORT_DIR)
         logger.info(subprocess.call(command, shell=True))
 
-    def send_report_by_dingtalk(self):
-        ...
-
     def convert_time(self, _time):
         result = ""
         if _time < 1000:
@@ -548,29 +511,34 @@ class Run(object):
             result += "{} 秒".format(_time)
         return result
 
-    def send_report_by_feishu(self, link, title=None, is_at_all=False):
+    def send_report_by_feishu(self, name, title=None, is_at_all=False, link=None, remarks=None):
+        """
+        发送飞书报告
+        :param name: 飞书在config的名字
+        :param title: 报告标题
+        :param is_at_all: 是否@所有人
+        :param link: 详情链接
+        :param remarks: 备注
+        :return:
+        """
         statistic, _time = self.get_result()
         logger.error(statistic)
         logger.error(_time)
+        if len(_time) == 0:
+            logger.error("请执行用例之后再进行报告发送")
+            return
         created_at = self.unix_by_datetime(int(_time.get('start')/1000))
         duration = self.convert_time(_time.get('duration'))
         if title is None:
             title = '接口测试报告'
-        if conf.settings.exists('robot'):
-            robot = conf.settings.robot
-            robot_type = robot.get('type', 'feishu')
-            robot_func = robot.get('func', 'send_lark_report')
-            if robot_type == "feishu":
-                client = conf.settings.feishu
-            if robot_func == 'send_lark_report':
-                response = client.send_lark_report(title, created_at, duration, self.get_env(), statistic, link, is_at_all)
-                logger.info(response.text)
-        else:
-            logger.error('请配置robot参数')
-
-    def send_feishu(self, access_token, secret, title, text):
-        response = robot.Robot().send_feishu(access_token, secret, title, text)
-        logger.info(response)
+        feishu = getattr(conf.settings, name)
+        conf.settings._report.button_element.insert(0, ['查看详情', link])
+        env = conf.settings._report.env
+        other_elements = conf.settings._report.other_element
+        button_config = conf.settings._report.button_element
+        response = feishu.send_report(title, created_at, duration, env, statistic, button_config=button_config,
+                                      is_at_all=is_at_all, other_elements=other_elements, remarks=remarks)
+        logger.info(response.text)
 
     def unix_by_datetime(self, unix_time):
         return datetime.datetime.fromtimestamp(int(float(str(unix_time)[:10]))).strftime("%Y-%m-%d %H:%M:%S")
